<style>
    h3.classhead{
        padding:15px; 
        background-color:#cccccc;
        border: 1px solid #bbbbbb;
        border-radius: 5px;
    }
</style>

## SupplyNetPy `Components.logger` Module

This module includes `GlobalLogger` class:

<div> <h3 class="classhead">Class GlobalLogger</h3></div>

The `GlobalLogger` class provides a flexible logging system for the SupplyNetPy simulations. It allows logging messages to both the console and a file, and can be easily enabled or disabled during runtime.

:::SupplyNetPy.Components.logger.GlobalLogger
